@@ -111,6 +111,11 @@ public:
 	 */
 	Account *registerAccount( Account *account );
 
+	/**
+	 * \brief Check if there is at least one account connected.
+	 * \return true if there at least one account connected, false otherwise.
+	 */
+	bool isAnyAccountConnected() const;
 
 	/**
 	 * Flag to be used in setOnlineStatus
@@ -129,9 +134,16 @@ public slots:
 	 * @param category is one of the Kopete::OnlineStatusManager::Categories
 	 * @param statusMessage is the new status message
 	 * @param flags is a bitmask of SetOnlineStatusFlag
+	 * @param forced is a boolean indicating that all accounts are required to change status
 	 */
 	void setOnlineStatus( /*Kopete::OnlineStatusManager::Categories*/ uint category,
-	                      const Kopete::StatusMessage &statusMessage = Kopete::StatusMessage(), uint flags=0);
+	                      const Kopete::StatusMessage &statusMessage,
+			      uint flags,
+			      bool forced );
+
+	KDE_DEPRECATED void setOnlineStatus( /*Kopete::OnlineStatusManager::Categories*/ uint category,
+	                      const Kopete::StatusMessage &statusMessage = Kopete::StatusMessage(),
+			      uint flags = 0 );
 
 	/**
 	 * @brief Set the given status message for all online accounts
@@ -184,14 +196,14 @@ private:
 	AccountManager();
 
 private slots:
-    /**
-     * Try to connect every account that should be connected automatically
-     */
-    void networkConnected();
-    /**
-     * Disconnect everything
-     */
-    void networkDisconnected();
+	/**
+	 * Try to connect every account that should be connected automatically
+	 */
+	void networkConnected();
+	/**
+	 * Disconnect everything
+	 */
+	void networkDisconnected();
 
 	void slotPluginLoaded( Kopete::Plugin *plugin );
 	void slotAccountOnlineStatusChanged(Kopete::Contact *c,
@@ -211,7 +223,6 @@ private slots:
 	void removeAccountInternal();
 
 private:
-	bool isAnyAccountConnected() const;
 	static AccountManager *s_self;
 	class Private;
 	Private * const d;
